@@ -60,30 +60,14 @@ class DbObject(object):
         return cls.filter(*args, **kwargs)[0]
 
     @classmethod
-    def filter(cls, *args, **kwargs):
+    def filter(cls, **kwargs):
         if not kwargs:
             raise NoParameters('No parameters provided')
-        filters = []
-        order = ""
 
-        for key, value in kwargs.iteritems():
-            if key.split('__')[0] == "max":
-                key_value = cls.adaptor.get_key_value(key.split('__')[1], value, cls.tablename, cls.fields)
+        filter = cls.adaptor.get_filter(tablename=cls.tablename,
+                                        fields=cls.fields,
+                                        filter=kwargs)
 
-                filters.append("%s<=%s" % key_value)
-            elif key.split('__')[0] == "min":
-                key_value = cls.adaptor.get_key_value(key.split('__')[1], value, cls.tablename, cls.fields)
-
-                filters.append("%s>=%s" % key_value)
-            elif key == "order_by":
-                continue
-            else:
-                key_value = cls.adaptor.get_key_value(key, value, cls.tablename, cls.fields)
-                filters.append("%s=%s" % key_value)
-        filter = (" AND ").join(filters)
-        if not filter:
-            filter = "1=1"
-        filter += " " + get_order(kwargs)
         return get_objects(cls, filter)
 
     @classmethod
@@ -152,10 +136,49 @@ class Adaptor():
     child adaptor
     """
 
+    def get_filter(self, **kwargs):
+        fields = kwargs['fields']
+        tablename = kwargs['tablename']
+        filter = kwargs['filter']
+
+        filters = []
+        order = ""
+        limit = ""
+
+        for key, value in filter.iteritems():
+            if key.split('__')[0] == "max":
+                key_value = self.get_key_value(key.split('__')[1], value, tablename, fields)
+                filters.append("%s<=%s" % key_value)
+
+            elif key.split('__')[0] == "min":
+                key_value = self.get_key_value(key.split('__')[1], value, tablename, fields)
+                filters.append("%s>=%s" % key_value)
+
+            elif key.split('__')[0] == "not":
+                key_value = self.get_key_value(key.split('__')[1], value, tablename, fields)
+                filters.append("%s!=%s" % key_value)
+
+            elif key == "order_by":
+                continue
+
+            elif key == "limit":
+                limit = " LIMIT %s" % value
+
+            else:
+                key_value = self.get_key_value(key, value, tablename, fields)
+                filters.append('%s=%s' % key_value)
+
+        filter = (" AND ").join(filters)
+        if not filter:
+            filter = "1=1"
+        filter += " " + get_order(kwargs['filter']) + limit
+        return filter
+
     def get_key_value(self, key, value, *args):
         tablename = args[0]
         fields = args[1]
-        if fields[key] == 'char':
+        quotes = ['char', 'date']
+        if fields[key] in quotes:
             value = "'%s'" % value
         return (key, value)
 
@@ -193,13 +216,44 @@ class PostgreSQLAdaptor(Adaptor):
         self.username = username
         self.password = password
 
+    def get_filter(self, **kwargs):
+        fields = kwargs['fields']
+        tablename = kwargs['tablename']
+        filter = kwargs['filter']
+
+        filters = []
+        order = ""
+        limit = ""
+
+        for key, value in filter.iteritems():
+            if key.split('__')[0] == "max":
+                key_value = self.get_key_value(key.split('__')[1], value, tablename, fields)
+
+                filters.append("%s<=%s" % key_value)
+            elif key.split('__')[0] == "min":
+                key_value = self.get_key_value(key.split('__')[1], value, tablename, fields)
+
+                filters.append("%s>=%s" % key_value)
+            elif key == "order_by":
+                continue
+            elif key == "limit":
+                limit = " LIMIT %s" % value
+            else:
+                key_value = self.get_key_value(key, value, tablename, fields)
+                filters.append('"%s"=%s' % key_value)
+        filter = (" AND ").join(filters)
+        if not filter:
+            filter = "1=1"
+        filter += " " + get_order(kwargs['filter']) + limit
+        return filter
+
     def get_connection(self):
         import psycopg2
         psycopg2.extensions.register_type(psycopg2.extensions.UNICODE)
         con = psycopg2.connect(host=self.host,
-                              database=self.database,
-                              user=self.username,
-                              password=self.password)
+                               database=self.database,
+                               user=self.username,
+                               password=self.password)
         return con
 
     def get_by_sql(self, query, *args):
@@ -210,7 +264,13 @@ class PostgreSQLAdaptor(Adaptor):
     def get_by_filter(self, filter, *args):
         tablename = args[0]
         fieldnames = args[1]
-        query = "SELECT %s FROM %s WHERE %s" % (', '.join(fieldnames),
+        key_string = ""
+
+        for item in fieldnames:
+            key_string += '"%s", ' %  item
+        key_string = key_string[:-2]
+
+        query = "SELECT %s FROM %s WHERE %s" % (key_string,
                                                 tablename,
                                                 filter)
         return self.get_by_sql(query, *args)
@@ -229,12 +289,18 @@ class PostgreSQLAdaptor(Adaptor):
         for key in empty_fields:
             field_values[key] = None
 
-        field_values.pop('id')
-        fieldnames.remove('id')
+        if field_values['id'] == None:
+            field_values.pop('id')
+            fieldnames.remove('id')
+
+        key_string = ""
+        for item in field_values.keys():
+            key_string += '"%s", ' %  item
+        key_string = key_string[:-2]
 
         query = "INSERT INTO %s (%s) VALUES (%s) RETURNING id" % (
                                        tablename,
-                                       ', '.join(field_values.keys()),
+                                       key_string,
                                        ', '.join(['%s'] * len(fieldnames)))
 
         fieldnames.insert(0, 'id')
@@ -250,19 +316,20 @@ class PostgreSQLAdaptor(Adaptor):
         fields = ""
         for key, value in cls.fields.items():
             if key == 'id':
-                fields += "id SERIAL PRIMARY KEY, "
+                fields += 'id SERIAL PRIMARY KEY, '
             if value == 'char':
-                fields += "%s VARCHAR(200) DEFAULT NULL, " % key
+                fields += '"%s" VARCHAR(200) DEFAULT NULL, ' % key
             if value == 'int' and not key == 'id':
-                fields += "%s INT DEFAULT 0, " % key
+                fields += '"%s" INT DEFAULT 0, ' % key
             if value == 'text':
-                fields += "%s TEXT DEFAULT NULL, " % key
+                fields += '"%s" TEXT DEFAULT NULL, ' % key
             if value == 'bool':
-                fields += "%s BOOLEAN, " % key
+                fields += '"%s" BOOLEAN, ' % key
             if value == 'date':
-                fields += "%s TIMESTAMP DEFAULT NULL, " % key
+                fields += '"%s" TIMESTAMP DEFAULT NULL, ' % key
+
         query = """CREATE TABLE IF NOT EXISTS %s (%s)""" % (cls.tablename,
-                                                              fields[:-2])
+                                                            fields[:-2])
         cls.raw(query)
         return True
 
